@@ -2,12 +2,12 @@ package LWP::Protocol;
 
 use base 'LWP::MemberMixin';
 
-our $VERSION = '6.19';
+our $VERSION = '6.20';
 
 use strict;
 use Carp ();
 use HTTP::Status ();
-use HTTP::Response;
+use HTTP::Response ();
 use Try::Tiny qw(try catch);
 
 my %ImplementedBy = (); # scheme => classname
